@@ -3,8 +3,9 @@
 # This is a sample settings.py that varies slightly from the default. Please see docs/configuration.rst or
 # trigger/conf/global_settings.py for the complete list of default settings.
 
-import os
 import IPy
+import os
+import socket
 
 #===============================
 # Global Settings
@@ -42,18 +43,6 @@ INTERNAL_NETWORKS = [
     IPy.IP("192.168.0.0/16"),
 ]
 
-# Who to email when things go well (e.g. load_acl --auto)
-SUCCESS_EMAILS = [
-    #'neteng@example.com',
-]
-
-# Who to email when things go not well 
-# --auto)
-FAILURE_EMAILS = [
-    #'primarypager@example.com',
-    #'secondarypager@example.com',
-]
-
 # The tuple of supported vendors derived from the values of VENDOR_MAP
 SUPPORTED_VENDORS = (
     'a10',
@@ -351,3 +340,42 @@ def _create_cm_ticket_stub(**args):
 # If you don't want to use this feature, just have the function return None.
 #CREATE_CM_TICKET = lambda a=None o, s: None
 CREATE_CM_TICKET = _create_cm_ticket_stub
+
+#===============================
+# Notifications
+#===============================
+# Email sender for integrated toosl. Usually a good idea to make this a
+# no-reply address.
+EMAIL_SENDER = 'nobody@not.real'
+
+# Who to email when things go well (e.g. load_acl --auto)
+SUCCESS_EMAILS = [
+    #'neteng@example.com',
+]
+
+# Who to email when things go not well (e.g. load_acl --auto)
+FAILURE_EMAILS = [
+    #'primarypager@example.com',
+    #'secondarypager@example.com',
+]
+
+# The default sender for integrated notifications. This defaults to the fqdn
+# for the localhost.
+NOTIFICATION_SENDER = socket.gethostname()
+
+# Destinations (hostnames, addresses) to notify when things go well.
+SUCCESS_RECIPIENTS = [
+    # 'foo.example.com',
+]
+
+# Destinations (hostnames, addresses) to notify when things go not well.
+FAILURE_RECIPIENTS = [
+    # socket.gethostname(), # The fqdn for the localhost
+]
+
+# This is a list of fully-qualified paths. Each path should end with a callable
+# that handles a notification event and returns ``True`` in the event of a
+# successful notification, or ``None``.
+NOTIFICATION_HANDLERS = [
+    'trigger.utils.notifications.handlers.email_handler',
+]
